# Installation

You can install the `seb` via pip from [PyPI]:

```bash
pip install seb
```

or from [GitHub] using:

```bash
pip install git+https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark
```

[pip]: https://pip.pypa.io/en/stable/
[PyPI]: https://pypi.org/project/scandinavian-embedding-benchmark/
[GitHub]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark